@@ -8,6 +8,7 @@
 import g
 import main
 import battle
+import monster
 
 #set to 1 whenever the player really shouldn't be moving.
 global has_dialog
@@ -46,11 +47,11 @@ def activate_line(x, y, z, command, tile_type=""):
 		if command.split(None, 2)[1].lower() == "random":
 			#battle random monster
 			i = g.mapname2zgrid(command.split(None, 2)[2])
-			temp = g.find_level_monster(i)
+			temp = monster.find_level_monster(i)
 		else:
 			#battle named monster
-			for monster_num in range(len(g.monster)):
-				if g.monster[monster_num][0].lower() == \
+			for monster_num in range(len(monster.monsters)):
+				if monster.monsters[monster_num].name.lower() == \
 				command.split(None, 1)[1].lower():
 					temp = monster_num
 					break
@@ -60,6 +61,14 @@ def activate_line(x, y, z, command, tile_type=""):
 		if temp != -1:
 			return_num = main.start_battle(temp)
 
+	elif switch == "delpix": #remove a picture from the tile.
+		try:
+			g.maps[z].field[y + g.ygrid][x + g.xgrid].del_pix(
+				g.tiles[command.split(None, 2)[1]])
+			return_num = 1
+		except ValueError:
+			return_num = 0
+
 	elif switch == "die":  #process endgame.txt script
 		g.hp = -1
 		for line in g.endgame_act:
@@ -75,23 +84,27 @@ def activate_line(x, y, z, command, tile_type=""):
 		amount = find_info[2].strip()
 		main.print_message("You found " + amount + " " + founditem + ".")
 		has_dialog = 1
-		if main.show_yesno("You found " + amount + " " + founditem + "! Would you like to pick it up ?"):
-                    if( g.take_inv_item(g.finditem(founditem)) != -1):
+		if main.show_yesno("You found " + amount + " " + founditem +
+				"! Would you like to pick it up ?"):
 			if(founditem == "gold"):
-			    g.gold = int(g.gold) + int(amount)
-                        main.print_message("You picked up " + amount + " " + founditem + ".")
-                        just_found = founditem
+				g.gold = int(g.gold) + int(amount)
+				main.print_message("You picked up " + amount + " " +
+						founditem + ".")
+				has_dialog = 0
+				return 1
+			if( g.take_inv_item(g.finditem(founditem)) != -1):
+				main.print_message("You picked up " + amount + " " +
+						founditem + ".")
+				has_dialog = 0
+				return 1
+			else:
+				main.print_message("You have no room for the " +
+						founditem + ".")
+				has_dialog = 0
+				return 0
 		else:
-			just_found = " "
-                has_dialog = 0
-
-	elif switch  == "got":
-		thing = command.split("\"", 2)[1].strip()
-                if(just_found == thing):
-		    just_found = " "
-                    return 1
-                else :
-                    return 0
+			has_dialog = 0
+			return 0
 
 	elif switch == "give":  #Change stats. Note that negatve numbers also work
 		switch2 = command.split(None, 2)[1].lower()
@@ -210,6 +223,13 @@ def activate_line(x, y, z, command, tile_type=""):
 		has_dialog = 0
 		return_num = 1
 
+	elif switch == "is_equipped": #is the given item equipped?
+		match = command.split(None, 1)[1].strip().lower()
+		for item_title in g.equip:
+			if g.item[item_title][0].strip().lower() == match:
+				return 1
+		return 0
+
 	elif switch == "item":  #give item
 		if g.take_inv_item(g.finditem(command.split(None, 1)[1])) == -1:
 			return_num = 0
@@ -239,6 +259,7 @@ def activate_line(x, y, z, command, tile_type=""):
 	elif switch == "pix":  #change tile picture
 		g.maps[z].field[y][x].pix = \
 			g.tiles[command.split(None, 2)[1]]
+		g.maps[z].field[y][x].addpix = []
 		return_num = 1
 
 	elif switch == "question":  #yes/no dialog box
@@ -260,16 +281,19 @@ def activate_line(x, y, z, command, tile_type=""):
 		else: return_num = 0
 
 	elif switch == "run":  #Run the actions of a different tile.
+		temp_zgrid = g.mapname2zgrid(command.split()[1])
+		if temp_zgrid == -1:
+			temp_zgrid = g.zgrid
+		x = int(command.split()[2])
+		y = int(command.split()[3])
 		return_num = 1
-		temp_zgrid = z
-		tile_type = command.split(None, 1)[1]
 		#if there are no actions, leave immediately
-		if len(g.maps[temp_zgrid].tiles[tile_type].actions) == 0: return 1
+		if len(g.maps[temp_zgrid].field[y][x].actions) == 0: return 1
 		i = 0
 		#go through all action lines.
-		while i < len(g.maps[temp_zgrid].tiles[tile_type].actions):
-			temp = activate_line(x, y, z,
-				g.maps[temp_zgrid].tiles[tile_type].actions[i])
+		while i < len(g.maps[temp_zgrid].field[y][x].actions):
+			temp = activate_line(x, y, temp_zgrid,
+				g.maps[temp_zgrid].field[y][x].actions[i])
 			if temp == "end": break
 			if main.dead_yet() == 1:
 				return_num = "end"
@@ -321,6 +345,8 @@ def activate_line(x, y, z, command, tile_type=""):
 			return_num = g.gold
 		elif switch2 == "exp":
 			return_num = g.exp
+		elif switch2 == "level":
+			return_num = g.level
 		elif switch2 == "skillpoints":
 			return_num = g.skillpoints
 		else:
