@@ -13,6 +13,7 @@ import os.path #for checking on existance of monster pixs.
 import g
 import main
 import action
+import monster
 
 mon_index = 0
 
@@ -39,11 +40,11 @@ cur_button = 0
 
 #refreshes the battle view. Call after changing anything.
 def refresh():
-	mon_hp.set(str(g.cur_mon_hp) + "/" + str(g.monster[mon_index][1]))
+	mon_hp.set(str(g.cur_mon_hp) + "/" + str(monster.monsters[mon_index].hp))
 
 	#hp/ep bars
 	canvas_mon_hp.delete("show_mon_hp")
-	temp_width = g.hpbar_width*g.cur_mon_hp/g.monster[mon_index][1]
+	temp_width = g.hpbar_width*g.cur_mon_hp/monster.monsters[mon_index].hp
 	if temp_width < 0: temp_width=0
 	canvas_mon_hp.create_rectangle(0, 0, temp_width,
 		g.hpbar_width/6, fill="#05BB05", tags="show_mon_hp")
@@ -79,9 +80,9 @@ def attack_monster():
 	global cur_mon_hp
 	#find the damage done
 	damage = g.die_roll(1, g.adj_attack + 2)
-	damage = damage - g.die_roll(1, g.monster[mon_index][3] + 2)
+	damage = damage - g.die_roll(1, monster.monsters[mon_index].defense + 2)
 	if damage > 0:
- 		main.print_message("You hit the " + g.monster[mon_index][0] +
+ 		main.print_message("You hit the " + monster.monsters[mon_index].name +
  			" for " + str(damage) + " damage.")
 		g.cur_mon_hp = g.cur_mon_hp - damage
 		#you kill it?
@@ -89,25 +90,26 @@ def attack_monster():
 			monster_dead()
 			return 0
 	else:
-		main.print_message("You miss the " + g.monster[mon_index][0] + ".")
+		main.print_message("You miss the " +
+				monster.monsters[mon_index].name + ".")
 
 
 #monster attacks you
 def attack_player():
-	damage = g.die_roll(1, g.monster[mon_index][2] + 2)
+	damage = g.die_roll(1, monster.monsters[mon_index].attack + 2)
 	damage = damage - g.die_roll(1, g.adj_defense + 2)
 	if damage > 0:
-		main.print_message("The " + g.monster[mon_index][0] +
+		main.print_message("The " + monster.monsters[mon_index].name +
 		" hits you for " + str(damage) + " damage.")
 		g.hp = g.hp - damage
 		#you dead yet?
 		if g.hp <= 0:
-			main.print_message("The " + g.monster[mon_index][0] +
+			main.print_message("The " + monster.monsters[mon_index].name +
 			" kills you.")
 			cur_button = 1
 
 	elif g.cur_mon_hp > 0:
-		main.print_message("The " + g.monster[mon_index][0] +
+		main.print_message("The " + monster.monsters[mon_index].name +
 		" misses you.")
 	refresh()
 
@@ -117,13 +119,13 @@ def monster_dead():
 	#make the display look better
 	g.cur_mon_hp = 0
 	#add info to listbox_move; add gold and xp
-	main.print_message("The " + g.monster[mon_index][0] +
+	main.print_message("The " + monster.monsters[mon_index].name +
 	" dies.")
-	gold = g.monster[mon_index][5]
+	gold = monster.monsters[mon_index].gold
 	g.gold = str(int(g.gold) + gold)
 	main.print_message("You find " + str(gold) + " gold,")
 
-	exp = g.monster[mon_index][4]
+	exp = monster.monsters[mon_index].exp
 	g.exp = int(g.exp) + exp
 	main.print_message("and get " + str(exp) + " experience.")
 
@@ -152,7 +154,8 @@ def runaway():
 		else:
 			if g.die_roll(1, 10) > 7:
 				window_battle.destroy()
-				main.print_message("You coward! You ran away from the " + g.monster[mon_index][0] + ".")
+				main.print_message("You coward! You ran away from the "
+					+ monster.monsters[mon_index].name + ".")
 				global did_run
 				did_run = 1
 			else:
@@ -198,12 +201,13 @@ def useitem():
 			damage = int(g.item[item_value][2])
 			g.drop_inv_item(g.find_inv_item(item_value))
 			if damage > 0:
-				main.print_message("The " + g.monster[mon_index][0] +
+				main.print_message("The " + monster.monsters[mon_index].name +
 					" is hit for " + str(damage) + " damage.")
 			g.cur_mon_hp = g.cur_mon_hp - damage
 			#you kill it?
 			if g.cur_mon_hp <= 0:
 				monster_dead()
+				return 0
 			else:
 				attack_player()
 	refresh()
@@ -251,7 +255,8 @@ def useskill():
 
 	elif g.skill[skill_index][1] == 1: #Sneak away
 		if g.die_roll(1, 10 + int(g.level)) > 5:
-			main.print_message("You coward! You ran away from the " + g.monster[mon_index][0] + ".")
+			main.print_message("You coward! You ran away from the " +
+				monster.monsters[mon_index].name + ".")
 			window_battle.destroy()
 			global did_run
 			did_run = 1
@@ -259,21 +264,23 @@ def useskill():
 		else:
 			main.print_message("You fail to sneak away.")
 			attack_player()
-	elif g.skill[skill_index][1] == 2: #Doublehit
+	elif g.skill[skill_index][1] == 2: #Frenzy
 		for i in range(2 + int(g.level)/3):
 			attack_monster()
 			if g.cur_mon_hp <= 0:
-				break
+				monster_dead()
+				return 0
 		if g.cur_mon_hp > 0:
 			attack_player()
 	elif g.skill[skill_index][1] == 3: #Dismember
 		damage = g.adj_attack + 2
-		main.print_message("You hit the " + g.monster[mon_index][0] +
+		main.print_message("You hit the " + monster.monsters[mon_index].name +
 			" for " + str(damage) + " damage.")
 		g.cur_mon_hp = g.cur_mon_hp - damage
 		#you kill it?
 		if g.cur_mon_hp <= 0:
 			monster_dead()
+			return 0
 		else:
 			attack_player()
 
@@ -295,7 +302,7 @@ def refresh_buttons():
 	if (cur_button == 0):
 		canvas_buttons.create_image(attack_button_loc, 0, anchor=NW,
 					image=attack_button_sel)
-		help_text.set("Attack monster")
+		help_text.set("Attack the " + monster.monsters[mon_index].name)
 	else: canvas_buttons.create_image(attack_button_loc, 0, anchor=NW,
 					image=attack_button)
 	if (cur_button == 1):
@@ -311,18 +318,16 @@ def refresh_buttons():
 			canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
 				image=leave_button_sel)
 			help_text.set("Leave")
-        elif g.hp <= 0:
-	        canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
+	elif g.hp <= 0: canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
 			image=quit_button)
-	elif g.cur_mon_hp > 0:
-	        canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
-			image=run_button)
-        else: canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
+	elif g.cur_mon_hp > 0: canvas_buttons.create_image(run_button_loc,
+			0, anchor=NW, image=run_button)
+	else: canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
 			image=leave_button)
 
 	if (cur_button == 2):
 		listbox_skill.select_clear(0, END)
-	        canvas_buttons.create_image(item_button_loc, 0,
+		canvas_buttons.create_image(item_button_loc, 0,
 			anchor=NW, image=item_button_sel)
 		if (len(listbox_item.curselection()) == 0):
 			help_text.set("No items")
@@ -331,11 +336,12 @@ def refresh_buttons():
 			except ValueError: pass
 			item_name = listbox_item.get(item_num[0])
 			help_text.set("Use your " + item_name)
-        else: canvas_buttons.create_image(item_button_loc, 0,
+	else: canvas_buttons.create_image(item_button_loc, 0,
 			anchor=NW, image=item_button)
+
 	if (cur_button == 3):
 		listbox_item.select_clear(0, END)
-	        canvas_buttons.create_image(skill_button_loc, 0,
+		canvas_buttons.create_image(skill_button_loc, 0,
 			anchor=NW, image=skill_button_sel)
 		if (len(listbox_skill.curselection()) == 0):
 			help_text.set("No useable skills")
@@ -344,7 +350,7 @@ def refresh_buttons():
 			except ValueError: pass
 			skill_name = listbox_skill.get(skill_num[0])
 			help_text.set("Use " + skill_name)
-        else: canvas_buttons.create_image(skill_button_loc, 0,
+	else: canvas_buttons.create_image(skill_button_loc, 0,
 			anchor=NW, image=skill_button)
 
 
@@ -355,7 +361,7 @@ def key_handler(key_name):
 	if (key_name == "esc"):
 		runaway()
 		return 0
-	elif  (key_name == "right"):
+	elif (key_name == "right"):
 		cur_button += 1
 		if (cur_button == 1): cur_button = 2 #run is now at end
 		elif (cur_button == 2): cur_button = 0 #run is now at end
@@ -369,7 +375,7 @@ def key_handler(key_name):
 		if (cur_button == 4): #switch to run
 			cur_button = 1
 			listbox_skill.select_clear(0, END)
-	elif  (key_name == "left"):
+	elif (key_name == "left"):
 		cur_button -= 1
 		if (cur_button == -1): cur_button = 1 #loop around
 		elif (cur_button == 1): cur_button = 0
@@ -513,7 +519,7 @@ def begin(mon_index_input):
 	global mon_index
 	mon_index = mon_index_input
 	global cur_mon_hp
-	g.cur_mon_hp = g.monster[mon_index][1]
+	g.cur_mon_hp = monster.monsters[mon_index].hp
 	global did_run
 	did_run = 0
 	global cur_button
@@ -524,16 +530,16 @@ def begin(mon_index_input):
 		highlightthickness=0, bg=bgcolour)
 	canvas_desc.grid(row=2, column=1, sticky=NSEW)
 	canvas_desc.create_text(1, 5, anchor=NW,
-			text=g.monster[mon_index][6], width=195)
+			text=monster.monsters[mon_index].description, width=195)
 
 	pic_frame = Frame(window_battle, bd=2, relief=SUNKEN, bg="#327a22")
 	pic_frame.grid(row=1, column=2, columnspan=3, rowspan=6, sticky=E)
 
 	global canvas_mon_pic
 	if os.path.isfile(g.mod_directory +
-			"/images/monsters/" + g.monster[mon_index][0] + ".png"):
+			"/images/monsters/" + monster.monsters[mon_index].name + ".png"):
 		monster_pic = ImageTk.PhotoImage(file=g.mod_directory +
-			"/images/monsters/" + g.monster[mon_index][0] + ".png")
+			"/images/monsters/" + monster.monsters[mon_index].name + ".png")
 	else:
 		monster_pic = ImageTk.PhotoImage(file=g.mod_directory +
 			"/images/monsters/generic.png")
@@ -553,8 +559,9 @@ def begin(mon_index_input):
 
 
 	#formatting for the labels.
-	label_formatting = Label(window_battle, text=g.monster[mon_index][0],
-		bg=bgcolour).grid(row=1, column=1, columnspan=2)
+	label_formatting = Label(window_battle,
+			text=monster.monsters[mon_index].name, bg=bgcolour).grid(row=1,
+			column=1, columnspan=2)
 	label_formatting = Label(pic_frame,
 		text="HP:", bg="#327a22").grid(row=5, column=2, sticky=W, padx=2)
 
@@ -564,9 +571,11 @@ def begin(mon_index_input):
 		bg="#327a22").grid(row=5, column=2, sticky=E, padx=2)
 
 	label_attack = Label(window_battle, text="Attack: " +
-	str(g.monster[mon_index][2]), bg=bgcolour).grid(row=4, column=1, sticky=W)
+	str(monster.monsters[mon_index].attack), bg=bgcolour).grid(row=4,
+			column=1, sticky=W)
 	label_defend = Label(window_battle, text="Defense: " +
-	str(g.monster[mon_index][3]), bg=bgcolour).grid(row=4, column=1, sticky=E)
+	str(monster.monsters[mon_index].defense), bg=bgcolour).grid(row=4,
+			column=1, sticky=E)
 
 	#help text
 	label_text = Label(window_battle,
@@ -681,7 +690,8 @@ def begin(mon_index_input):
 	listbox_item.bind("<ButtonRelease-1>", mouse_handler_item)
 	listbox_skill.bind("<ButtonRelease-1>", mouse_handler_skill)
 
-	main.print_message("The " + g.monster[mon_index][0] + " attacks you.")
+	main.print_message("The " + monster.monsters[mon_index].name +
+		" attacks you.")
 
 	refresh()
 	refresh_buttons()
