@@ -5,7 +5,7 @@
 #This file contains everything that needs to be accessed by most or all files.
 
 
-#Dragon Hunt 3.29. Released under the GPL. Copyright 2004
+#Dragon Hunt 3.30. Released under the GPL. Copyright 2004
 #(Note to self: when changing version, change variables.txt, README.txt,
 # and setup.py.)
 
@@ -19,6 +19,7 @@ from os import path, mkdir, remove, walk
 
 #needed for scripting
 from scripting import *
+import monster
 
 
 #This will be displayed on the Title screen and Main screen.
@@ -88,8 +89,8 @@ xgrid = 0
 ygrid = 0
 zgrid = 1
 
-#controls timed effects such as healing. Loops around every 60 turns (0-59);
-#use % command to control.
+#controls timed effects such as healing. Loops around every 30 turns (0-29);
+#controls perturn.txt.
 timestep = 0
 
 #dictionary of script variables.
@@ -112,6 +113,9 @@ hpbar_width = 0
 #current module directory
 mod_directory = ""
 
+#per turn scripting, for hp recovery and the like.
+per_turn_script = []
+
 #Has tk been inited yet? Used between rpg.py and new_game.py to decide where
 #to init tk.
 init_tk_already = 0
@@ -250,11 +254,12 @@ def init_data():
 	read_maps()
 	read_scripts()
 	read_items()
-	read_monster()
+	monster.read_monster()
 	global game_name
 	game_name = read_game_name()
 	read_variables()
 	read_shops()
+	read_perturn()
 
 #Get the name of the module from the variables.txt file. Note that this
 #does not set the game name, only returns it. This lets it be used in rpg.py
@@ -312,6 +317,40 @@ def read_dice(variable, dice_string):
 	new_game_dice[variable].append(int(second))
 	new_game_dice[variable].append(int(third))
 
+#reads the file data/perturn.txt. Expects mod_directory to be set.
+def read_perturn():
+	cur_turns = []
+	temp_cur_turns = []
+	global per_turn_script
+	for i in range(30):
+		per_turn_script.append([])
+	file = open(mod_directory + "/data/perturn.txt", 'r')
+	line = file.readline()
+	while (line != ''):
+		line = line.strip()
+		if (line[:1] == "#" or line[:1] == ""):
+			line = file.readline()
+			continue
+		#allow the \ line-continuation character.
+		while line[-1:] == "\\":  #really a single backslash, BTW.
+			line = line[:-1] + file.readline()[:-1]
+
+		line = line.strip()
+		if line[:1] == ":": #start defining more tiles.
+			cur_turns = []
+			temp_cur_turns = line[1:].split(",")
+			for turn in temp_cur_turns:
+				if turn.strip().isdigit():
+					cur_turns.append(int(turn.strip()))
+
+		#give scripting to the current tiles
+		else:
+			for turn_num in cur_turns:
+				per_turn_script[turn_num].append(line)
+		#ready another line
+		line = file.readline()
+	file.close()
+
 
 #Item arrays. Each item is a separate line in the array. Each line goes:
 #name, type, quality, price, description
@@ -363,7 +402,7 @@ def read_items():
 		for i in range(5):
 			item_array[i] = item_array[i].strip()
 
-		#actually add the monster
+		#actually add the item
 		additem(item_array[0], int(item_array[1]),
 			int(item_array[2]), int(item_array[3]), item_array[4])
 
@@ -422,68 +461,6 @@ addskill("Frenzy",  2, 2, 30,
 	"Your next attack will try to hit more than once")
 
 
-#Monster array. Each monster is a separate line in the array. Each line goes:
-#name, hp, attack, defense, XP on death, gold on death, description.
-monster = []
-
-#Add an monster to the monster[] array
-def addmonster(mon_name, mon_hp, mon_attack, mon_defense, mon_xp,
-			mon_gold, mon_desc):
-	monster.append([])
-	i = len(monster)
-	monster[i-1].append(mon_name)
-	monster[i-1].append(mon_hp)
-	monster[i-1].append(mon_attack)
-	monster[i-1].append(mon_defense)
-	monster[i-1].append(mon_xp)
-	monster[i-1].append(mon_gold)
-	monster[i-1].append(mon_desc)
-
-
-#find an appropriate monster for the dungeon level.
-#-1 is returned if no monsters are available for this level;
-#otherwise, the position in maps[zgrid].monster[] is returned.
-
-def find_level_monster(level):
-	if len(maps[level].monster) == 0: return -1
-	mon_name = maps[level].monster[
-		int(random() * len(maps[level].monster))]
-	for i in range(len(monster)):
-		if mon_name == monster[i][0]:
-			return i
-	print "monster " + mon_name + " not found in monster.txt."
-	return -1
-
-#read monster.txt. This is called on startup.
-def read_monster():
-	monster_loc = g.mod_directory + "/data/monster.txt"
-	monster_file = open(monster_loc, 'r')
-
-	#go through all lines of the file
-	monster_line = monster_file.readline()
-	while monster_line != '':
-		#strip out spaces/tabs
-		monster_line = monster_line.strip()
-
-		#ignore blank lines and comments
-		if monster_line[:1] == "#" or monster_line[:1] == "":
-			monster_line = monster_file.readline()
-			continue
-
-		#split the line and clean up any remaining problems
-		monster_array = monster_line.split("/")
-		for i in range(6):
-			monster_array[i] = monster_array[i].strip()
-
-		#actually add the monster
-		addmonster(monster_array[0], int(monster_array[1]),
-			int(monster_array[2]), int(monster_array[3]),
-				int(monster_array[4]), int(monster_array[5]), monster_array[6])
-
-		#ready another line
-		monster_line = monster_file.readline()
-
-	monster_file.close()
 
 
 
@@ -560,11 +537,11 @@ def load_tiles():
 		(head, tail) = path.split(root)
 		if (tail != "CVS"):
 			for tilename in files:
-			    #if image is in a sub-dir:
-			    if (root != g.mod_directory + "/images/tiles/"):
-				i = len(g.mod_directory + "/images/tiles/")
-				tiles[root[i:] + "/" + tilename] = \
-				    ImageTk.PhotoImage(file=root + "/" + tilename)
-			    else: #if image is in root dir
-				tiles[tilename] = \
-				    ImageTk.PhotoImage(file=root + "/" + tilename)
+				#if image is in a sub-dir:
+				if (root != g.mod_directory + "/images/tiles/"):
+					i = len(g.mod_directory + "/images/tiles/")
+					tiles[root[i:] + "/" + tilename] = \
+						ImageTk.PhotoImage(file=root + "/" + tilename)
+				else: #if image is in root dir
+					tiles[tilename] = \
+						ImageTk.PhotoImage(file=root + "/" + tilename)
