@@ -12,14 +12,16 @@ from Tkinter import *
 import ImageTk
 import Image
 #import re
-from os import path, mkdir, remove, walk, listdir
+from os import path, mkdir, remove, walk, listdir, getcwd
+import tkMessageBox
 import load_map
+import re
 
 import g
 import scripting
 
-mapsize_x =25
-mapsize_y =25
+mapsize_x =15
+mapsize_y =15
 
 portal_x = 0
 portal_y = 0
@@ -32,8 +34,6 @@ window.title("Map Editor")
 
 cur_tile = ""
 cur_tile_num = 0
-cur_x = 0
-cur_y = 0
 border = "rock.png"
 background = "grass.png"
 map_name = "map.txt"
@@ -88,7 +88,17 @@ def create_map():
 	canvas_map = Canvas(top, width=g.tilesize*portalsize,
 		height=g.tilesize*portalsize, highlightthickness=0)
 	canvas_map.grid(column=0, row=0)
+	global y_scroll
+	y_scroll = Scrollbar(top, orient=VERTICAL, command=map_from_scroll_y)
+	y_scroll.grid(column=1, row=0, sticky=NS)
+	global x_scroll
+	x_scroll = Scrollbar(top, orient=HORIZONTAL, command=map_from_scroll_x)
+	x_scroll.grid(column=0, row=1, sticky=EW)
+
 	canvas_map.bind("<Button-1>", map_callback)
+	canvas_map.bind("<Button-4>", move_up)
+	canvas_map.bind("<Button-5>", move_down)
+	canvas_map.bind("<B1-Motion>", map_callback)
 	window.bind("<Up>", move_up)
 	window.bind("<Down>", move_down)
 	window.bind("<Left>", move_left)
@@ -99,26 +109,27 @@ def create_map():
 	portal_y = 0
 
 	refresh_map()
+	scroll_from_map()
 
-def move_up(event):
+def move_up(event=None):
 	global portal_y
 	if portal_y > 0:
 		portal_y -= 1
 	refresh_map()
 
-def move_down(event):
+def move_down(event=None):
 	global portal_y
 	if portal_y + portalsize < mapsize_y:
 		portal_y += 1
 	refresh_map()
 
-def move_left(event):
+def move_left(event=None):
 	global portal_x
 	if portal_x > 0:
 		portal_x -= 1
 	refresh_map()
 
-def move_right(event):
+def move_right(event=None):
 	global portal_x
 	if portal_x + portalsize < mapsize_x:
 		portal_x += 1
@@ -171,21 +182,123 @@ def refresh_map():
 					canvas_map.create_image((x-portal_x)*g.tilesize,
 						(y-portal_y)*g.tilesize, anchor=NW,
 						image=g.tiles[line.strip().split()[1].strip()])
-
+				elif len(line.strip().split()) >= 8 and \
+				line.strip().split()[6].strip().lower() == "addpix":
+					canvas_map.create_image((x-portal_x)*g.tilesize,
+						(y-portal_y)*g.tilesize, anchor=NW,
+						image=g.tiles[line.strip().split()[7].strip()])
+	scroll_from_map()
 
 #set tile at x, y to name.
 def set_tile(x, y, name):
 	if x >= mapsize_x: return
 	if y >= mapsize_y: return
-	for line_num in range(len(cur_map.field[y][x].onload)):
-		if cur_map.field[y][x].onload[line_num].split()[0].strip().lower() == "pix":
-			cur_map.field[y][x].onload[line_num] = "pix " + name
-			temp_name = name
-	for line_num in range(len(cur_map.field[y][x].onload)):
-		if cur_map.field[y][x].onload[line_num].split()[0].strip().lower() == "walk":
-			cur_map.field[y][x].onload[line_num] = "walk " + walk[temp_name]
+
+	#if the tile is an item, add it to the current tile
+	tile_prefix = name.split("/", 1)[0]
+	if tile_prefix == "items":
+		add_item(x, y, name)
+	else:
+		temp_name = name
+		for line_num in range(len(cur_map.field[y][x].onload)):
+			if cur_map.field[y][x].onload[line_num].split()[0].strip().lower() == "pix":
+				cur_map.field[y][x].onload[line_num] = "pix " + name
+				temp_name = name
+		for line_num in range(len(cur_map.field[y][x].onload)):
+			if cur_map.field[y][x].onload[line_num].split()[0].strip().lower() == "walk":
+				cur_map.field[y][x].onload[line_num] = "walk " + walk[temp_name]
 	refresh_map()
 
+#add name item to tile at x, y
+def add_item(x, y, name):
+	item = name.split("/", 1)[1]
+	item = item[0:len(item)-4]
+	item_name = re.sub("_", " ", item)
+	cur_map.field[y][x].onload.append("if var " + item + "_added | end | addpix " + name)
+	cur_map.field[y][x].onload.append("set " + item + "_added = 1")
+	global amount
+	amount = "AMOUNT"
+	set_item_amount()
+	cur_map.field[y][x].actions.append("if var got_" + item + "| end | find \""  + item_name + "\" " + amount)
+	cur_map.field[y][x].actions.append("if got \"" + item_name + "\" | set got_" + item + " = 1 | end")
+	cur_map.field[y][x].actions.append("delpix " + name)
+
+def set_item_amount():
+	temp_amount = StringVar()
+	global amount_window
+	amount_window = Toplevel(window)
+	label_format = Label(amount_window, text="Item Amount: \n")
+	label_format.grid(row=0, column=0, sticky=E)
+	amount_textbox = Entry(amount_window, textvariable=temp_amount)
+	amount_textbox.grid(row=0, column=1, sticky=W)
+	ok_button = Button(amount_window, text="OK",
+		command=(lambda: really_set_amount( temp_amount.get())))
+	ok_button.grid(row=2, column=0)
+	cancel_button = Button(amount_window, text="Cancel",
+		command=(lambda: close_amount_window()))
+	cancel_button.grid(row=2, column=1)
+	amount_window.master.wait_window(amount_window)
+
+def really_set_amount(temp_amount):
+	try:
+		amount_window.destroy()
+	except:
+		pass
+	global amount
+	amount = temp_amount
+
+def close_amount_window():
+	amount_window.destroy()
+
+def map_from_scroll_y(scrolltype, step, what=None):
+	global portal_y
+	if scrolltype=="moveto":
+		portal_y = int(float(step)*mapsize_y)
+		if portal_y+portalsize > mapsize_y: portal_y = mapsize_y - portalsize
+		if portal_y < 0: portal_y = 0
+		refresh_map()
+	else:
+		if what=="units":
+			if step=="1": move_down()
+			else: move_up()
+		else:
+			if step=="1":
+				portal_y += 5
+				if portal_y+portalsize > mapsize_y: portal_y = mapsize_y - portalsize
+			else:
+				portal_y -= 5
+				if portal_y < 0: portal_y = 0
+			refresh_map()
+
+def map_from_scroll_x(scrolltype, step, what=None):
+	global portal_x
+	if scrolltype=="moveto":
+		portal_x = int(float(step)*mapsize_x)
+		if portal_x+portalsize > mapsize_x: portal_x = mapsize_x - portalsize
+		if portal_x < 0: portal_x = 0
+		refresh_map()
+	else:
+		if what=="units":
+			if step=="1": move_right()
+			else: move_left()
+		else:
+			if step=="1":
+				portal_x += 5
+				if portal_x+portalsize > mapsize_x: portal_x = mapsize_x - portalsize
+			else:
+				portal_x -= 5
+				if portal_x < 0: portal_x = 0
+			refresh_map()
+
+def scroll_from_map():
+	scrolltop = float(portal_y)/mapsize_y
+	scrollbot = float((portal_y+portalsize))/mapsize_y
+	y_scroll.set(scrolltop, scrollbot)
+
+	scrollleft = float(portal_x)/mapsize_x
+	scrollright = float((portal_x+portalsize))/mapsize_x
+	x_scroll.set(scrollleft, scrollright)
+
 #this loads the various tiles.
 def load_tiles():
 	global tiles
@@ -280,7 +393,7 @@ def display_tiles(set = "default"):
 		end_in_png = file_prefix[len(file_prefix)-4:len(file_prefix)]
 		#if not in a sub-dir, then this tile is in default set
 		if(end_in_png == ".png"):
-		    file_prefix = "default"
+			file_prefix = "default"
 
 		#only show tiles in appropriate set (ie. correct subdir)
 		if(file_prefix == set):
@@ -300,9 +413,9 @@ def refresh_tiles():
 	for cur in range(tile_set_size):
 		tile_button = tilebox[cur]
 		if(cur != cur_tile_num):
-		   tile_button.config(bg="black")
+			tile_button.config(bg="black")
 		else:
-		   tile_button.config(bg="red")
+			tile_button.config(bg="red")
 
 def quit_command(event=0):
 	try:
@@ -328,7 +441,7 @@ def check_repeat_tile(x, y):
 #save map to map dir and call it map.txt
 def save_map(event=0):
 	set_codes()
-	map_loc = g.mod_directory + "/data/maps/" + "map.txt"
+	map_loc = g.mod_directory + "/data/maps/" + map_name
 	print "Saving map to " + map_loc
 	map_file = open(map_loc, 'w')
 	count = 0
@@ -389,6 +502,7 @@ def do_load_map():
 	portal_x = 0
 	portal_y = 0
 	refresh_map()
+	scroll_from_map()
 
 #given input and output maps, copies the important parts.
 def copy_map(output_map, input_map):
@@ -424,6 +538,42 @@ def tiles_equal(tile1, tile2):
 			return 0
 	return 1
 
+
+#brings up the monster edit window.
+def edit_monsters(i):
+	global monster_window
+	monster_window = Toplevel(window)
+	monster_window.title("Edit Monsters:")
+
+	monster_textbox = Text(monster_window, width=50, height=8)
+	for monster_name in cur_map.monster:
+		monster_textbox.insert(END, monster_name + "\n")
+	monster_textbox.grid(row=0, column=0, columnspan=2)
+
+	ok_button = Button(monster_window, text="OK",
+		command=(lambda: change_monsters(monster_textbox.get(1.0, END))))
+	ok_button.grid(row=2, column=0)
+	cancel_button = Button(monster_window, text="Cancel",
+		command=(lambda: close_monster_window()))
+	cancel_button.grid(row=2, column=1)
+	monster_window.master.wait_window(monster_window)
+
+#given a \n separated list of monsters, place into the monster list
+def change_monsters(monster_text):
+	cur_map.monster = []
+	monster_array = monster_text.split("\n")
+	for monster_name in monster_array:
+		if monster_name.strip() != "":
+			cur_map.monster.append(monster_name)
+	close_monster_window()
+
+def close_monster_window():
+	try:
+		monster_window.destroy()
+	except: pass
+
+
+
 #brings up the change mapsize window.
 def change_mapsize(size):
 	temp_x = StringVar()
@@ -448,7 +598,8 @@ def change_mapsize(size):
 
 #given x and y in tiles, resizes the map, destroying and creating tiles as needed.
 def really_change_mapsize(x, y):
-	size_window.destroy()
+	try: size_window.destroy()
+	except: pass
 	global mapsize_x
 	global mapsize_y
 	mapsize_x = int(x)
@@ -473,11 +624,20 @@ def really_change_mapsize(x, y):
 	global portal_y
 	portal_x = 0
 	portal_y = 0
+	line = "Reset border and background for new map size ? "  \
+		"(This will clear the contents of the map.)"
+	if ask_yesno(line):
+		set_border(border)
+		set_bkg(background)
 	refresh_map()
 
 def close_size_window():
 	size_window.destroy()
 
+def ask_yesno(line=None):
+	if window.state() != "normal": return 0
+	return tkMessageBox.askyesno("Map Editor Question", line, parent=window)
+
 def toggle_grid():
 	global tilegrid
 	if tilegrid == 0:
@@ -497,29 +657,10 @@ def make_menus():
 	mbutton = Menubutton(menubar, text='Main Menu', bg=bgcolour)
 	picks = Menu(mbutton, bg=bgcolour)
 	mbutton.config(menu=picks)
-	picks.add_command(label='Load Map', command=do_load_map)
+	picks.add_command(label='Load Map ...', command=do_load_map)
 	picks.add_command(label='Save', command=save_map)
 	picks.add_command(label='Quit', command=quit_command)
 	mbutton.grid(row=0, column=1, sticky=NW)
-	#background menu
-	mbutton = Menubutton(menubar, text='Set Background', bg=bgcolour)
-	picks = Menu(mbutton, bg=bgcolour)
-	mbutton.config(menu=picks)
-	picks.add_command(label='water', command=(lambda x="water/water.png":set_bkg(x)))
-	picks.add_command(label='dirt', command=(lambda x="underground/dirt.png":set_bkg(x)))
-	picks.add_command(label='void', command=(lambda x="underground/void.png":set_bkg(x)))
-	picks.add_command(label='grass', command=(lambda x="grass.png":set_bkg(x)))
-	mbutton.grid(row=0, column=2, sticky=NW)
-	#border menu
-	mbutton = Menubutton(menubar, text='Set Border', bg=bgcolour)
-	picks = Menu(mbutton, bg=bgcolour)
-	mbutton.config(menu=picks)
-	picks.add_command(label='water', command=(lambda x="water/water.png":set_border(x)))
-	picks.add_command(label='rock', command=(lambda x="rock.png":set_border(x)))
-	picks.add_command(label='hills', command=(lambda x="hills/hills_n4.png":set_border(x)))
-	picks.add_command(label='cave', command=(lambda x="underground/rock.png":set_border(x)))
-	picks.add_command(label='void', command=(lambda x="underground/void.png":set_border(x)))
-	mbutton.grid(row=0, column=3, sticky=NW)
 	#tile set menu
 	mbutton = Menubutton(menubar, text='Tile Set', bg=bgcolour)
 	picks = Menu(mbutton, bg=bgcolour)
@@ -532,12 +673,42 @@ def make_menus():
 			else:
 				picks.add_command(label=tail, command=(lambda x=tail:display_tiles(x)))
 	mbutton.grid(row=0, column=4, sticky=NW)
-	#mapsize menu
-	mbutton = Menubutton(menubar, text='Map Options', bg=bgcolour)
-	picks = Menu(mbutton, bg=bgcolour)
-	mbutton.config(menu=picks)
-	picks.add_command(label='Adjust map size', command=(lambda x=0:change_mapsize(x)))
+
+	#Settings Parent menu
+	mbutton = Menubutton(menubar, text='Map Settings', bg=bgcolour)
+	map_options = Menu(mbutton, bg=bgcolour)
+	mbutton.config(menu=map_options)
+
+	#mapsize submenu
+	mapsize_menu = Menu(map_options, bg=bgcolour)
+	map_options.add_cascade(label='Map Size',menu=mapsize_menu)
+	mapsize_menu.add_command(label='Custom Map Size ...', command=(lambda x=0:change_mapsize(x)))
+	mapsize_menu.add_command(label='15x15', command=(lambda x=15:really_change_mapsize(x, x)))
+	mapsize_menu.add_command(label='20x20', command=(lambda x=20:really_change_mapsize(x, x)))
+	mapsize_menu.add_command(label='25x25', command=(lambda x=25:really_change_mapsize(x, x)))
+
+	#background submenu
+	background_menu = Menu(map_options, bg=bgcolour)
+	map_options.add_cascade(label='Background',menu=background_menu)
+	background_menu.add_command(label='water', command=(lambda x="water/water.png":set_bkg(x)))
+	background_menu.add_command(label='dirt', command=(lambda x="underground/dirt.png":set_bkg(x)))
+	background_menu.add_command(label='void', command=(lambda x="underground/void.png":set_bkg(x)))
+	background_menu.add_command(label='grass', command=(lambda x="grass.png":set_bkg(x)))
+
+	#border submenu
+	border_menu = Menu(map_options, bg=bgcolour)
+	map_options.add_cascade(label='Border',menu=border_menu)
+	border_menu.add_command(label='water', command=(lambda x="water/water.png":set_border(x)))
+	border_menu.add_command(label='rock', command=(lambda x="rock.png":set_border(x)))
+	border_menu.add_command(label='hills', command=(lambda x="hills/hills_n4.png":set_border(x)))
+	border_menu.add_command(label='cave', command=(lambda x="underground/rock.png":set_border(x)))
+	border_menu.add_command(label='void', command=(lambda x="underground/void.png":set_border(x)))
+
+	map_options.add_command(label='Edit Monsters', command=(lambda x=0:edit_monsters(x)))
+
+
 	mbutton.grid(row=0, column=5, sticky=NW)
+
 	#display menu
 	mbutton = Menubutton(menubar, text='Display', bg=bgcolour)
 	picks = Menu(mbutton, bg=bgcolour)
@@ -596,6 +767,7 @@ if (len(array_mods) == 1):
 	create_map()
 	setup_tilebox()
 	display_tiles("default")
+	toggle_grid()
 else:
 	global window_sel_game #reduced form of rpg.py
 	window_sel_game = Toplevel()
