@@ -25,6 +25,8 @@ class tile:
 		self.actions.append(action)
 	def add_pix(self, picture):
 		self.addpix.append(picture)
+	def del_pix(self, picture):
+		self.addpix.remove(picture)
 
 class map:
 	def __init__(self, mapname):
@@ -49,7 +51,8 @@ class map:
 			map_line = map_line.strip()
 
 			#ignore blank lines and comments
-			if map_line[:1] == "#" or map_line[:1] == "" or map_line[:1] == "\n":
+			if map_line[:1] == "#" or map_line[:1] == "" \
+											or map_line[:1] == "\n":
 				map_line = map_file.readline()
 				continue
 
@@ -124,7 +127,7 @@ class map:
 						continue
 
 					#allow the \ line-continuation character.
-					while map_line[-1:] == "\\":  #really a single backslash, BTW.
+					while map_line[-1:] == "\\":  #really a single backslash.
 						map_line = map_line[:-1] + map_file.readline()[:-1] #for \n
 
 
